@@ -1,12 +1,10 @@
 """
-Application services for OpenProtein.
+Application interfaces for OpenProtein.
 
 isort:skip_file
 """
 
-from .assaydata import AssayDataAPI
-from .train import TrainingAPI
-from .design import DesignAPI
+from .assaydata import DataAPI
 from .align import AlignAPI
 from .embeddings import EmbeddingsAPI
 from .fold import FoldAPI
@@ -14,4 +12,4 @@ from .job import JobsAPI
 from .svd import SVDAPI
 from .umap import UMAPAPI
 from .predictor import PredictorAPI
-from .designer import DesignerAPI
+from .designer import DesignAPI
